@@ -71,15 +71,15 @@ TopLevel::TopLevel() : KSystemTray(), ticketWatch(0), m_refreshTimer(0), m_reque
 	TDEConfig *config = kapp->config();
 	config->setGroup("Kerberos");
 
-	getNewTGTAct = new TDEAction(i18n("&Obtain New Ticket Granting Ticket"), "add_user", 0, TQT_TQOBJECT(this), TQT_SLOT(getNewTGT()), actionCollection(), "getnewtgt");
-	getNewSTAct = new TDEAction(i18n("&Obtain New Primary Service Ticket"), "add_user", 0, TQT_TQOBJECT(this), TQT_SLOT(getNewServiceTicket()), actionCollection(), "getnewserviceticket");
-	getNewStandardSTAct = new TDEAction(i18n("&Obtain Authenticated Service Ticket"), "add_user", 0, TQT_TQOBJECT(this), TQT_SLOT(getNewServiceTicketWithExistingCreds()), actionCollection(), "getstandardserviceticket");
-	destroyAllAct = new TDEAction(i18n("&Destroy All Tickets"), "delete_user", 0, TQT_TQOBJECT(this), TQT_SLOT(destroyAllTickets()), actionCollection(), "destroyall");
-	confAct = new TDEAction(i18n("&Configure..."), "configure", 0, TQT_TQOBJECT(this), TQT_SLOT(config()), actionCollection(), "configure");
+	getNewTGTAct = new TDEAction(i18n("&Obtain New Ticket Granting Ticket"), "add_user", 0, this, TQ_SLOT(getNewTGT()), actionCollection(), "getnewtgt");
+	getNewSTAct = new TDEAction(i18n("&Obtain New Primary Service Ticket"), "add_user", 0, this, TQ_SLOT(getNewServiceTicket()), actionCollection(), "getnewserviceticket");
+	getNewStandardSTAct = new TDEAction(i18n("&Obtain Authenticated Service Ticket"), "add_user", 0, this, TQ_SLOT(getNewServiceTicketWithExistingCreds()), actionCollection(), "getstandardserviceticket");
+	destroyAllAct = new TDEAction(i18n("&Destroy All Tickets"), "delete_user", 0, this, TQ_SLOT(destroyAllTickets()), actionCollection(), "destroyall");
+	confAct = new TDEAction(i18n("&Configure..."), "configure", 0, this, TQ_SLOT(config()), actionCollection(), "configure");
 
 	// create app menu (displayed on right-click)
 	menu = new TQPopupMenu();
-	connect(menu, TQT_SIGNAL(activated(int)), this, TQT_SLOT(menuAction(int)));
+	connect(menu, TQ_SIGNAL(activated(int)), this, TQ_SLOT(menuAction(int)));
 
 	KHelpMenu* help = new KHelpMenu(this, TDEGlobal::instance()->aboutData(), false);
 	TDEPopupMenu* helpMnu = help->menu();
@@ -92,7 +92,7 @@ TopLevel::TopLevel() : KSystemTray(), ticketWatch(0), m_refreshTimer(0), m_reque
 	menu->insertSeparator();
 	confAct->plug(menu);
 	menu->insertItem(SmallIcon("help"), i18n("&Help"), helpMnu);
-	menu->insertItem(SmallIcon("system-log-out"), i18n("Quit"), kapp, TQT_SLOT(quit()));
+	menu->insertItem(SmallIcon("system-log-out"), i18n("Quit"), kapp, TQ_SLOT(quit()));
 
 	// Set up card monitoring
 	TDEGenericDevice *hwdevice;
@@ -156,13 +156,13 @@ void TopLevel::setupTimers() {
 
 	if (!m_refreshTimer) {
 		m_refreshTimer = new TQTimer(this);
-		connect(m_refreshTimer, TQT_SIGNAL(timeout()), this, TQT_SLOT(updateTicketList()));
+		connect(m_refreshTimer, TQ_SIGNAL(timeout()), this, TQ_SLOT(updateTicketList()));
 		m_refreshTimer->start(10*1000, false);
 	}
 
 	if (!m_requestUpdateTimer) {
 		m_requestUpdateTimer = new TQTimer(this);
-		connect(m_requestUpdateTimer, TQT_SIGNAL(timeout()), this, TQT_SLOT(updateTicketList()));
+		connect(m_requestUpdateTimer, TQ_SIGNAL(timeout()), this, TQ_SLOT(updateTicketList()));
 	}
 }
 
@@ -177,9 +177,9 @@ void TopLevel::updateTicketList() {
 
 	if (!ticketWatch) {
 		ticketWatch = new KDirWatch();
-		connect(ticketWatch, TQT_SIGNAL(dirty(const TQString&)), this, TQT_SLOT(requestTicketListUpdate()));
-		connect(ticketWatch, TQT_SIGNAL(created(const TQString&)), this, TQT_SLOT(requestTicketListUpdate()));
-		connect(ticketWatch, TQT_SIGNAL(deleted(const TQString&)), this, TQT_SLOT(requestTicketListUpdate()));
+		connect(ticketWatch, TQ_SIGNAL(dirty(const TQString&)), this, TQ_SLOT(requestTicketListUpdate()));
+		connect(ticketWatch, TQ_SIGNAL(created(const TQString&)), this, TQ_SLOT(requestTicketListUpdate()));
+		connect(ticketWatch, TQ_SIGNAL(deleted(const TQString&)), this, TQ_SLOT(requestTicketListUpdate()));
 		ticketWatch->addFile(m_ticketFile);
 		ticketWatch->startScan();
 	}
@@ -327,10 +327,10 @@ void TopLevel::resizeEvent (TQResizeEvent *)
 
 /** Handle mousePressEvent */
 void TopLevel::mousePressEvent(TQMouseEvent *event) {
-	if (event->button() == Qt::LeftButton) {
+	if (event->button() == TQt::LeftButton) {
 		showTicketList();
 	}
-	else if (event->button() == Qt::RightButton) {
+	else if (event->button() == TQt::RightButton) {
 		updateMenu();
 		menu->popup(TQCursor::pos());
 	}
